@@ -26,17 +26,17 @@ def get_log_messages(txnData):
     return txnData.get('meta', {}).get('logMessages', [])
 
 def get_instructions(txnData):
-  return txnData.get('transaction', {}).get('message', {}).get('instructions', [])
+  return txnData['transaction']['message']['instructions']
 
 def get_inner_instructions(txnData):
-  return txnData.get('meta', {}).get('innerInstructions', {})[0].get('instructions', [])
+  return txnData['meta']['innerInstructions'][0]['instructions']
 
 def update_instructions(txnData,instructions):
   txnData['transaction']['message']['instructions'] = instructions
   return  txnData
 
 def update_inner_instructions(txnData,inner_instructions):
-  txnData['meta']['innerInstructions']['instructions'] = inner_instructions
+  txnData['meta']['innerInstructions'][0]['instructions'] = inner_instructions
   return txnData
 
 def get_post_balance_fromm_txn(txnData):
